@@ -22,6 +22,8 @@
 
 #include <Plasma/DataEngine>
 
+namespace Plasma {
+
 /**
  * @class WeatherLocation
  *
@@ -32,7 +34,7 @@ class WeatherLocation : public QObject
     Q_OBJECT
 public:
     explicit WeatherLocation(QObject *parent = nullptr);
-    virtual ~WeatherLocation();
+    ~WeatherLocation() override;
 
     /**
      * Get default source
@@ -57,10 +59,9 @@ public Q_SLOTS:
     void dataUpdated(const QString &source, const Plasma::DataEngine::Data &data);
 
 private:
-    class Private;
-    Private * const d;
-
-    Q_PRIVATE_SLOT(d, void validatorFinished(const QMap<QString, QString> &results))
+    const QScopedPointer<class WeatherLocationPrivate> d;
 };
 
+}
+
 #endif
